==> libhdf4_4.0.2.orig.tar.gz: libhdf4-4.0.2.orig/hdf/src/cnone.h <==
/****************************************************************************
 * NCSA HDF                                                                 *
 * Software Development Group                                               *
 * National Center for Supercomputing Applications                          *
 * University of Illinois at Urbana-Champaign                               *
 * 605 E. Springfield, Champaign IL 61820                                   *
 *                                                                          *
 * For conditions of distribution and use, see the accompanying             *
 * hdf/COPYING file.                                                        *
 *                                                                          *
 ****************************************************************************/

/* cnone.h,v 1.3 1994/06/29 13:03:31 koziol Exp */

/*-----------------------------------------------------------------------------
 * File:    cnone.h
 * Purpose: Header file for "none" encoding information.
 * Dependencies: should only be included from hcompi.h
 * Invokes: none
 * Contents: Structures & definitions for "none" encoding.  This header
 *              should only be included in hcomp.c and cnone.c.
 * Structure definitions:
 * Constant definitions:
 *---------------------------------------------------------------------------*/

/* avoid re-inclusion */
#ifndef __CNONE_H
#define __CNONE_H

#if defined c_plusplus || defined __cplusplus
extern      "C"
{
#endif                          /* c_plusplus || __cplusplus */

/*
   ** from cnone.c
 */

    extern int32 HCPcnone_stread
                (accrec_t * rec);

    extern int32 HCPcnone_stwrite
                (accrec_t * rec);

    extern int32 HCPcnone_seek
                (accrec_t * access_rec, int32 offset, int origin);

    extern int32 HCPcnone_inquire
                (accrec_t * access_rec, int32 *pfile_id, uint16 *ptag, uint16 *pref,
               int32 *plength, int32 *poffset, int32 *pposn, int16 *paccess,
                 int16 *pspecial);

    extern int32 HCPcnone_read
                (accrec_t * access_rec, int32 length, VOIDP data);

    extern int32 HCPcnone_write
                (accrec_t * access_rec, int32 length, const VOIDP data);

    extern intn HCPcnone_endaccess
                (accrec_t * access_rec);

#if defined c_plusplus || defined __cplusplus
}
#endif                          /* c_plusplus || __cplusplus */

/* "none" [en|de]coding information */
typedef struct
{
    intn        space_holder;   /* merely a space holder so compilers don't barf */
}
comp_coder_none_info_t;

#ifndef CNONE_MASTER
extern funclist_t cnone_funcs;  /* functions to perform run-length encoding */
#else
funclist_t  cnone_funcs =
{                               /* functions to perform run-length encoding */
    HCPcnone_stread,
    HCPcnone_stwrite,
    HCPcnone_seek,
    HCPcnone_inquire,
    HCPcnone_read,
    HCPcnone_write,
    HCPcnone_endaccess
};
#endif

#endif /* __CNONE_H */

==> libhdf4_4.2.10-3.2.tar.gz: libhdf4-4.2.10/hdf/src/cnone.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * Copyright by The HDF Group.                                               *
 * Copyright by the Board of Trustees of the University of Illinois.         *
 * All rights reserved.                                                      *
 *                                                                           *
 * This file is part of HDF.  The full HDF copyright notice, including       *
 * terms governing use, modification, and redistribution, is contained in    *
 * the files COPYING and Copyright.html.  COPYING can be found at the root   *
 * of the source code distribution tree; Copyright.html can be found at      *
 * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
 * access to either file, you may request a copy from help@hdfgroup.org.     *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/* $Id: cnone.h 4932 2007-09-07 17:17:23Z bmribler $ */

/*-----------------------------------------------------------------------------
 * File:    cnone.h
 * Purpose: Header file for "none" encoding information.
 * Dependencies: should only be included from hcompi.h
 * Invokes: none
 * Contents: Structures & definitions for "none" encoding.  This header
 *              should only be included in hcomp.c and cnone.c.
 * Structure definitions:
 * Constant definitions:
 *---------------------------------------------------------------------------*/

/* avoid re-inclusion */
#ifndef __CNONE_H
#define __CNONE_H

#if defined c_plusplus || defined __cplusplus
extern      "C"
{
#endif                          /* c_plusplus || __cplusplus */

/*
   ** from cnone.c
 */

    extern int32 HCPcnone_stread
                (accrec_t * rec);

    extern int32 HCPcnone_stwrite
                (accrec_t * rec);

    extern int32 HCPcnone_seek
                (accrec_t * access_rec, int32 offset, int origin);

    extern int32 HCPcnone_inquire
                (accrec_t * access_rec, int32 *pfile_id, uint16 *ptag, uint16 *pref,
               int32 *plength, int32 *poffset, int32 *pposn, int16 *paccess,
                 int16 *pspecial);

    extern int32 HCPcnone_read
                (accrec_t * access_rec, int32 length, void * data);

    extern int32 HCPcnone_write
                (accrec_t * access_rec, int32 length, const void * data);

    extern intn HCPcnone_endaccess
                (accrec_t * access_rec);

#if defined c_plusplus || defined __cplusplus
}
#endif                          /* c_plusplus || __cplusplus */

/* "none" [en|de]coding information */
typedef struct
{
    intn        space_holder;   /* merely a space holder so compilers don't barf */
}
comp_coder_none_info_t;

#ifndef CNONE_MASTER
extern funclist_t cnone_funcs;  /* functions to perform run-length encoding */
#else
funclist_t  cnone_funcs =
{                               /* functions to perform run-length encoding */
    HCPcnone_stread,
    HCPcnone_stwrite,
    HCPcnone_seek,
    HCPcnone_inquire,
    HCPcnone_read,
    HCPcnone_write,
    HCPcnone_endaccess
};
#endif

#endif /* __CNONE_H */
